/*
 * Copyright James Morse Y2K +1, +2, +3
 * This is GPLed software 
 * please read COPYING
 *
 */

#ifndef KB_H
#define KB_H 

/* get the key board the way we like it */
void init_kb ();

/* put it back how we found it */
void close_kb ();

/* did the user hit a key? */
int kb_hit ();

/* what was it? */
int read_kb ();

#endif /* KB_H */

